4Suite API Documentation: Ft.Xml.Xslt.CommentElement

4Suite™ API Documentation

# ► Module Ft.Xml.Xslt.CommentElement

xsl:comment instruction implementation

    Copyright 2006 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: CommentElement |  |  |  | Globals: XSL_NAMESPACE

## Classes

class CommentElement(Ft.Xml.Xslt.StylesheetTree.XsltElement)

  ### Methods

  instantiate(self, context, processor)
    Overrides: instantiate from class XsltElement

  ### Methods inherited from class Ft.Xml.Xslt.StylesheetTree.XsltElement

  __init__, __str__, appendChild, expandQName, insertChild, parseAVT, parseExpression, parsePattern, processChildren, splitQName

  ### Methods inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  idle, isLastChild, isPseudoNode, pprint, prime, setup

  ### Members

  category = 0
  content = <Ft.Xml.Xslt.ContentInfo.Rep instance>
  legalAttrs = {}

  ### Members inherited from class Ft.Xml.Xslt.StylesheetTree.XsltElement

  validator

  ### Members inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  attributes, baseUri, children, columnNumber, doesIdle, doesPrime, doesSetup, expandedName, importIndex, lineNumber, nodeName, parent, root

## Globals

XSL_NAMESPACE = u'http://www.w3.org/1999/XSL/Transform'